@@ -12,6 +12,7 @@ import subprocess
 
 class Network:
 
+    # noinspection PyBroadException,PyBroadException
     @staticmethod
     def address():
         hostname = socket.gethostname()
@@ -79,8 +80,3 @@ class Network:
             })
 
         return details
-
-    @staticmethod
-    def get():
-
-        return
